@@ -1,6 +1,8 @@
 from flask import request, jsonify
+from functools import wraps
 
 def is_json_request(func):
+    @wraps(func)
     def wrapper(*args, **kwds):
         json = request.json
         if not json and request.method != "GET":
@@ -9,6 +11,7 @@ def is_json_request(func):
     return wrapper
 
 def json_renderer(func):
+    @wraps(func)
     def wrapper(*args, **kwds):
         result = func(*args, **kwds)
         return jsonify(result)
